@@ -10,15 +10,14 @@ from __future__ import (
 import locale
 
 # Local imports
-from natsort.locale_help import use_pyicu
-from natsort.compat.py23 import py23_str
+from natsort.compat.py23 import py23_str, py23_unichr, py23_range
 
 
 def load_locale(x):
     """ Convenience to load a locale, trying ISO8859-1 first."""
     try:
         locale.setlocale(locale.LC_ALL, str('{0}.ISO8859-1'.format(x)))
-    except:
+    except locale.Error:
         locale.setlocale(locale.LC_ALL, str('{0}.UTF-8'.format(x)))
 
 # Check if de_DE is installed.
@@ -28,23 +27,19 @@ try:
 except locale.Error:
     has_locale_de_DE = False
 
-# Make a function that will return the appropriate
-# strxfrm for the current locale.
-if use_pyicu:
-    from natsort.locale_help import get_pyicu_transform
-    from locale import getlocale
-
-    def get_strxfrm():
-        return get_pyicu_transform(getlocale())
-else:
-    from natsort.locale_help import strxfrm
-
-    def get_strxfrm():
-        return strxfrm
-
 # Depending on the python version, use lower or casefold
 # to make a string lowercase.
 try:
     low = py23_str.casefold
 except AttributeError:
     low = py23_str.lower
+
+# There are some unicode values that are known failures on BSD systems
+# that has nothing to do with natsort (a ValueError is raised by strxfrm).
+# Let's filter them out.
+try:
+    bad_uni_chars = set(py23_unichr(x) for x in py23_range(0X10fefd,
+                                                           0X10ffff+1))
+except ValueError:
+    # Narrow unicode build... no worries.
+    bad_uni_chars = set()
