@@ -3,20 +3,18 @@
 Test the natsort command-line tool functions.
 """
 from __future__ import print_function, unicode_literals
-import pytest
 import re
 import sys
 from pytest import raises
 from compat.mock import patch, call
-from compat.hypothesis import (
-    assume,
+from hypothesis import (
     given,
-    sampled_from,
+)
+from hypothesis.strategies import (
     integers,
     floats,
-    tuples,
-    text,
-    use_hypothesis,
+    lists,
+    data,
 )
 from natsort.__main__ import (
     main,
@@ -25,7 +23,6 @@ from natsort.__main__ import (
     keep_entry_range,
     exclude_entry,
     sort_and_print_entries,
-    py23_str,
 )
 
 
@@ -68,8 +65,8 @@ def test_main_passes_arguments_with_all_command_line_options():
 
 class Args:
     """A dummy class to simulate the argparse Namespace object"""
-    def __init__(self, filter, reverse_filter, exclude, as_path, reverse):
-        self.filter = filter
+    def __init__(self, filt, reverse_filter, exclude, as_path, reverse):
+        self.filter = filt
         self.reverse_filter = reverse_filter
         self.exclude = exclude
         self.reverse = reverse
@@ -173,17 +170,17 @@ def test_range_check_returns_range_as_is_but_with_floats_if_first_is_less_than_s
     assert range_check(6.4, 30) == (6.4, 30.0)
 
 
-@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
-@given(x=integers(), y=integers())
-def test_range_check_returns_range_as_is_but_with_floats_if_first_is_less_than_second(x, y):
-    assume(x < y)
-    assert range_check(x, y) == (float(x), float(y))
+@given(x=integers(), data=data())  # Defer data selection for y till test is run.
+def test_range_check_returns_range_as_is_but_with_floats_if_first_is_less_than_second(x, data):
+    # Pull data such that the first is less than the second.
+    y = data.draw(integers(min_value=x + 1))
+    assert range_check(x, y) == (x, y)
 
 
-@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
-@given(x=floats(), y=floats())
-def test_range_check_returns_range_as_is_but_with_floats_if_first_is_less_than_second2(x, y):
-    assume(x < y)
+@given(x=floats(allow_nan=False, min_value=-1E8, max_value=1E8), data=data())  # Defer data selection for y till test is run.
+def test_range_check_returns_range_as_is_but_with_floats_if_first_is_less_than_second2(x, data):
+    # Pull data such that the first is less than the second.
+    y = data.draw(floats(min_value=x + 1.0, max_value=1E9, allow_nan=False))
     assert range_check(x, y) == (x, y)
 
 
@@ -193,12 +190,12 @@ def test_range_check_raises_ValueError_if_second_is_less_than_first_example():
     assert str(err.value) == 'low >= high'
 
 
-@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
-@given(x=floats(), y=floats())
-def test_range_check_raises_ValueError_if_second_is_less_than_first(x, y):
-    assume(x >= y)
+@given(x=floats(allow_nan=False), data=data())  # Defer data selection for y till test is run.
+def test_range_check_raises_ValueError_if_second_is_less_than_first(x, data):
+    # Pull data such that the first is greater than or equal to the second.
+    y = data.draw(floats(max_value=x, allow_nan=False))
     with raises(ValueError) as err:
-        range_check(x, x)
+        range_check(x, y)
     assert str(err.value) == 'low >= high'
 
 
@@ -208,16 +205,15 @@ def test_check_filter_returns_None_if_filter_evaluates_to_False():
     assert check_filter(None) is None
 
 
-def test_check_filter_converts_filter_numbers_to_floats_if_filter_is_valid_example():
-    assert check_filter([(6, 7)]) == [(6.0, 7.0)]
-    assert check_filter([(6, 7), (2, 8)]) == [(6.0, 7.0), (2.0, 8.0)]
+def test_check_filter_returns_input_as_is_if_filter_is_valid_example():
+    assert check_filter([(6, 7)]) == [(6, 7)]
+    assert check_filter([(6, 7), (2, 8)]) == [(6, 7), (2, 8)]
 
 
-@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
-@given(x=tuples(integers(), integers(), floats(), floats()), y=tuples(integers(), floats(), floats(), integers()))
-def test_check_filter_converts_filter_numbers_to_floats_if_filter_is_valid(x, y):
-    assume(all(i < j for i, j in zip(x, y)))
-    assert check_filter(list(zip(x, y))) == [(float(i), float(j)) for i, j in zip(x, y)]
+@given(x=lists(integers(), min_size=1), data=data())  # Defer data selection for y till test is run.
+def test_check_filter_returns_input_as_is_if_filter_is_valid(x, data):
+    y = [data.draw(integers(min_value=val + 1)) for val in x]  # ensure y is element-wise greater than x
+    assert check_filter(list(zip(x, y))) == [(i, j) for i, j in zip(x, y)]
 
 
 def test_check_filter_raises_ValueError_if_filter_is_invalid_example():
@@ -226,10 +222,9 @@ def test_check_filter_raises_ValueError_if_filter_is_invalid_example():
     assert str(err.value) == 'Error in --filter: low >= high'
 
 
-@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
-@given(x=tuples(integers(), integers(), floats(), floats()), y=tuples(integers(), floats(), floats(), integers()))
-def test_check_filter_raises_ValueError_if_filter_is_invalid(x, y):
-    assume(any(i >= j for i, j in zip(x, y)))
+@given(x=lists(integers(), min_size=1), data=data())  # Defer data selection for y till test is run.
+def test_check_filter_raises_ValueError_if_filter_is_invalid(x, data):
+    y = [data.draw(integers(max_value=val)) for val in x]    # ensure y is element-wise less than or equal to x
     with raises(ValueError) as err:
         check_filter(list(zip(x, y)))
     assert str(err.value) == 'Error in --filter: low >= high'
@@ -239,57 +234,17 @@ def test_keep_entry_range_returns_True_if_any_portion_of_input_is_between_the_ra
     assert keep_entry_range('a56b23c89', [0], [100], int, re.compile(r'\d+'))
 
 
-@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
-@given(tuples(text(), integers(1, 99), text(), integers(1, 99), text()))
-def test_keep_entry_range_returns_True_if_any_portion_of_input_is_between_the_range_bounds(x):
-    s = ''.join(map(py23_str, x))
-    assume(any(0 < int(i) < 100 for i in re.findall(r'\d+', s) if re.match(r'\d+$', i)))
-    assert keep_entry_range(s, [0], [100], int, re.compile(r'\d+'))
-
-
 def test_keep_entry_range_returns_True_if_any_portion_of_input_is_between_any_range_bounds_example():
     assert keep_entry_range('a56b23c89', [1, 88], [20, 90], int, re.compile(r'\d+'))
 
 
-@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
-@given(tuples(text(), integers(2, 89), text(), integers(2, 89), text()))
-def test_keep_entry_range_returns_True_if_any_portion_of_input_is_between_any_range_bounds(x):
-    s = ''.join(map(py23_str, x))
-    assume(any((1 < int(i) < 20) or (88 < int(i) < 90) for i in re.findall(r'\d+', s) if re.match(r'\d+$', i)))
-    assert keep_entry_range(s, [1, 88], [20, 90], int, re.compile(r'\d+'))
-
-
 def test_keep_entry_range_returns_False_if_no_portion_of_input_is_between_the_range_bounds_example():
     assert not keep_entry_range('a56b23c89', [1], [20], int, re.compile(r'\d+'))
 
 
-@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
-@given(tuples(text(), integers(min_value=21), text(), integers(min_value=21), text()))
-def test_keep_entry_range_returns_False_if_no_portion_of_input_is_between_the_range_bounds(x):
-    s = ''.join(map(py23_str, x))
-    assume(all(not (1 <= int(i) <= 20) for i in re.findall(r'\d+', s) if re.match(r'\d+$', i)))
-    assert not keep_entry_range(s, [1], [20], int, re.compile(r'\d+'))
-
-
 def test_exclude_entry_returns_True_if_exlcude_parameters_are_not_in_input_example():
     assert exclude_entry('a56b23c89', [100, 45], int, re.compile(r'\d+'))
 
 
-@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
-@given(tuples(text(), integers(min_value=0), text(), integers(min_value=0), text()))
-def test_exclude_entry_returns_True_if_exlcude_parameters_are_not_in_input(x):
-    s = ''.join(map(py23_str, x))
-    assume(not any(int(i) in (23, 45, 87) for i in re.findall(r'\d+', s) if re.match(r'\d+$', i)))
-    assert exclude_entry(s, [23, 45, 87], int, re.compile(r'\d+'))
-
-
 def test_exclude_entry_returns_False_if_exlcude_parameters_are_in_input_example():
     assert not exclude_entry('a56b23c89', [23], int, re.compile(r'\d+'))
-
-
-@pytest.mark.skipif(not use_hypothesis, reason='requires python2.7 or greater')
-@given(tuples(text(), sampled_from([23, 45, 87]), text(), sampled_from([23, 45, 87]), text()))
-def test_exclude_entry_returns_False_if_exlcude_parameters_are_in_input(x):
-    s = ''.join(map(py23_str, x))
-    assume(any(int(i) in (23, 45, 87) for i in re.findall(r'\d+', s) if re.match(r'\d+$', i)))
-    assert not exclude_entry(s, [23, 45, 87], int, re.compile(r'\d+'))
